

set -ex



pip check
python -c "import json_stream_rs_tokenizer; print('json_stream_rs_tokenizer.rust_tokenizer_or_raise()'); json_stream_rs_tokenizer.rust_tokenizer_or_raise()"
pytest -v tests -k "not (test_overconsumption_load_ends_at_doc_end)" --ignore=tests/test_via_benchmark.py --ignore=tests/test_using_json_stream_tokenizer_tests.py --ignore=tests/test_exceptions.py --ignore=tests/test_integers.py --ignore=tests/test_large_integers.py --ignore=tests/test_unicode_surrogate_pairs.py
exit 0
